export type TerminalMessageClass = 'success' | 'error' | 'info' | 'warning' | 'system';
export type TerminalMessageType = 'cmdLine' | 'normal' | 'json' | 'code' | 'table' | 'html' | 'ansi';
export type TerminalCursorStyle = 'block' | 'underline' | 'bar' | 'none';
export interface EditorConfig {
    open: boolean;
    focus: boolean;
    value: string;
    onClose: null | Function;
    onFocus?: Function;
    onBlur?: Function;
}
export type Position = {
    x: number;
    y: number;
};
export type DragConfig = {
    width: number | string;
    height: number | string;
    zIndex?: string;
    init?: Position;
    pinned?: boolean;
};
export type ScreenType = {
    xs?: boolean;
    sm?: boolean;
    md?: boolean;
    lg?: boolean;
    xl?: boolean;
};
export type Command = {
    key: string;
    title?: string;
    group?: string;
    usage?: string;
    description?: string;
    example?: Array<CommandExample>;
};
export type CommandExample = {
    cmd: string;
    des?: string;
};
export type CmdHistory = {
    cmdLog: string[];
    cmdIdx: number;
};
export type Options = {
    highlight: object;
    codemirror: object;
    themes: Record<string, string>;
};
export type MessageContentTable = {
    head: string[];
    rows: string[][];
};
export type MessageGroup = {
    fold: boolean;
    logs: Message[];
    tag?: string;
};
export type Message = {
    type?: TerminalMessageType;
    content: string | number | object | MessageContentTable | Array<any>;
    class?: TerminalMessageClass;
    tag?: string;
    depth?: number;
};
export type AskConfig = {
    isPassword: boolean;
    question: string;
    autoReview: boolean;
    callback?: (value: string) => void;
};
export type InputTipItem = {
    content: string;
    description?: string;
    command?: Command;
};
export type CharWidth = {
    en?: number;
    cn?: number;
};
export type TerminalElementInfo = {
    pos: Position;
    screenWidth: number;
    screenHeight: number;
    clientWidth: number;
    clientHeight: number;
    charWidth: CharWidth;
};
export type CommandSortHandlerFunc = (a: any, b: any) => number;
export type InputFilterFunc = (str1: string, str2: string, event: InputEvent | CompositionEvent) => string | null;
export type CommandFormatterFunc = (cmd: string) => string;
export type TerminalApiListenerFunc = (type: string, options?: any) => any | void;
export type SuccessFunc = (message?: Message | Array<Message> | string | TerminalFlash | TerminalAsk) => void;
export type FailedFunc = (message: string) => void;
export type PushMessageBeforeFunc = (message: Message, name: String) => void;
/**
 * 提示选择处理函数
 *
 * @param command       当前用户输入的完整命令行
 * @param cursorIndex   当前光标所处位置
 * @param item          用户选择提示项
 * @param callback      填充结束后需调用此函数返回新的命令行
 */
export type InputTipsSelectHandlerFunc = (command: string, cursorIndex: number, item: InputTipItem, callback: (cmd: string) => void) => void;
/**
 * 用户自定义命令搜索提示实现
 *
 * @param command       当前用户输入的完整命令行
 * @param cursorIndex   当前光标所处位置
 * @param commandStore  命令集合
 * @param callback      搜索结束回调，回调格式为一个数组
 */
export type InputTipsSearchHandlerFunc = (command: string, cursorIndex: number, commandStore: Command[], callback: (tips: InputTipItem[], openTips?: boolean) => void) => void;
declare class TerminalCallback {
    onFinishListener: Function;
    finish(): void;
    onFinish(callback: Function): void;
}
export declare class TerminalAsk extends TerminalCallback {
    handler: Function;
    ask(options: AskConfig): void;
    onAsk(callback: (config: AskConfig) => void): void;
}
export declare class TerminalFlash extends TerminalCallback {
    handler: Function;
    flush(msg: string): void;
    onFlush(callback: (msg: string) => void): void;
}
export declare class TerminalStore {
    storageKey: string;
    dataMap: Object;
    constructor(key?: string);
    push(name: string, cmd: string): void;
    store(): void;
    getData(name: string): CmdHistory;
    getLog(name: string): string[];
    clear(name: string): void;
    clearAll(): void;
    getIdx(name: string): number;
    setIdx(name: string, idx: number): void;
}
export interface TerminalApiData {
    pool: {
        [key: string]: TerminalApiListenerFunc;
    };
    options?: Options;
}
export declare class TerminalApi {
    data: TerminalApiData;
    constructor(data: TerminalApiData);
    post(name: string, event: string, options?: any): any;
    pushMessage(name: string, options: Message | Array<Message> | string): any;
    appendMessage(name: string, options: string): any;
    fullscreen(name: string): any;
    isFullscreen(name: string): any;
    dragging(name: string, options: Position): any;
    execute(name: string, options: string): any;
    focus(name: string, options: boolean): any;
    elementInfo(name: string): any;
    textEditorOpen(name: string, options?: EditorSetting): any;
    textEditorClose(name: string, options?: any): string | any;
    clearLog(name: string, options?: any): any;
    getCommand(name: string, options?: any): string;
    setCommand(name: string, options?: any): string | any;
    switchAllFoldState(name: string, options: boolean): any;
    jumpToBottom(name: string, options: boolean): any;
}
export interface EditorSetting {
    content: string;
    onClose: Function;
}
export {};
